==> makeen-expressionengine-0.0.51.tgz: package/src/types/typeMapper.ts <==
﻿import { typeMapperRegistry } from './typeMapperRegistry';
import { List } from 'typescript-dotnet-commonjs/System/Collections/List'
import { Type } from 'typescript';
import { outputVariables } from '../utils/outputVariables';
import { getType } from '../utils/reflectionExtender';
import { DictionaryObject } from '../utils/dictionaryObject';
export class typeMapper {

    public static nullToType<T>(tType: Type): T {
        return typeMapperRegistry.CurrentTypeMapper.nullToTypeGeneric<T>(tType) as T;
    }

    public static nullToAny(targetType: any): Object {
        return typeMapperRegistry.CurrentTypeMapper.nullToType(targetType) as Object;
    }

    public static toType1<T>(item: Object, tType?: Type): T | undefined {
        let outV = new outputVariables();
        return typeMapperRegistry.CurrentTypeMapper.toTypeGeneric<T>(item, getType(item), outV);
    }

    public static toType2<T>(item: Object, tType: Type, success: outputVariables): T {
        return typeMapperRegistry.CurrentTypeMapper.toTypeGeneric<T>(item, tType, success);
    }

    public static toType3<T>(item: Object, tType: Type): Object {
        let outv = new outputVariables();
        return typeMapperRegistry.CurrentTypeMapper.toTypeGeneric<T>(item, tType, outv);
    }

    public static toType<T>(item: Object, targetType?: T, /* out */success?: outputVariables): Object | undefined {
        if (success != null)
            return typeMapperRegistry.CurrentTypeMapper.toType(item, targetType, /* out */success);
        else if (targetType != null)
            return typeMapperRegistry.CurrentTypeMapper.toType(item, targetType, new outputVariables());
    }

    public static toArray<T>(str: string, tType: Type): T[] | undefined {
        return typeMapperRegistry.CurrentTypeMapper.toArray<T>(str, tType);
    }

    public static toList<T>(str: string, tType: Type): List<T> | undefined {
        return typeMapperRegistry.CurrentTypeMapper.toList<T>(str, tType);
    }

    public static toDictionary<T>(str: string, tType: Type): DictionaryObject | undefined {
        return typeMapperRegistry.CurrentTypeMapper.toDictionary<T>(str, tType);
    }
}

==> makeen-expressionengine-0.0.63.tgz: package/src/types/typeMapper.ts <==
﻿import { typeMapperRegistry } from './typeMapperRegistry';
import { List } from 'typescript-dotnet-commonjs/System/Collections/List'
import { Type } from 'typescript';
import { outputVariables } from '../utils/outputVariables';
import { getType } from '../utils/reflectionExtender';
import { DictionaryObject } from '../utils/dictionaryObject';
export class typeMapper {

     static nullToType<T>(tType: Type): T {
        return typeMapperRegistry.CurrentTypeMapper.nullToTypeGeneric<T>(tType) as T;
    }

     static nullToAny(targetType: any): Object {
        return typeMapperRegistry.CurrentTypeMapper.nullToType(targetType) as Object;
    }

     static toType1<T>(item: Object, tType?: Type): T | undefined {
        let outV = new outputVariables();
        return item as T;
        //return typeMapperRegistry.CurrentTypeMapper.toTypeGeneric<T>(item, getType(item), outV);
    }

     static toType2<T>(item: Object, tType: Type, success: outputVariables): T {
        return typeMapperRegistry.CurrentTypeMapper.toTypeGeneric<T>(item, tType, success);
    }

     static toType3<T>(item: Object, tType: Type): Object {
        let outv = new outputVariables();
        return typeMapperRegistry.CurrentTypeMapper.toTypeGeneric<T>(item, tType, outv);
    }

     static toType<T>(item: Object, targetType?: T, /* out */success?: outputVariables): Object | undefined {
        if (success != null)
            return typeMapperRegistry.CurrentTypeMapper.toType(item, targetType, /* out */success);
        else if (targetType != null)
            return typeMapperRegistry.CurrentTypeMapper.toType(item, targetType, new outputVariables());
    }

     static toArray<T>(str: string, tType: Type): T[] | undefined {
        return typeMapperRegistry.CurrentTypeMapper.toArray<T>(str, tType);
    }

     static toList<T>(str: string, tType: Type): List<T> | undefined {
        return typeMapperRegistry.CurrentTypeMapper.toList<T>(str, tType);
    }

     static toDictionary<T>(str: string, tType: Type): DictionaryObject | undefined {
        return typeMapperRegistry.CurrentTypeMapper.toDictionary<T>(str, tType);
    }
}
